@@ -16,7 +16,8 @@ from omotes_sdk_protocol.job_pb2 import (
 )
 from omotes_sdk.job import Job
 from omotes_sdk.queue_names import OmotesQueueNames
-from omotes_sdk.workflow_type import WorkflowType
+from omotes_sdk.types import ParamsDict
+from omotes_sdk.workflow_type import WorkflowType, WorkflowTypeManager
 
 logger = logging.getLogger("omotes_sdk")
 
@@ -70,20 +71,30 @@ class JobSubmissionCallbackHandler:
             self.callback_on_status_update(self.job, status_update)
 
 
+class UnknownWorkflowException(Exception):
+    """Thrown if a job is submitted using an unknown workflow type."""
+
+    ...
+
+
 class OmotesInterface:
     """SDK interface for other applications to communicate with OMOTES."""
 
     broker_if: BrokerInterface
     """Interface to RabbitMQ broker."""
+    workflow_type_manager: WorkflowTypeManager
+    """Manager of all possible workflows."""
 
-    def __init__(self, rabbitmq_config: RabbitMQConfig):
+    def __init__(self, rabbitmq_config: RabbitMQConfig, possible_workflows: WorkflowTypeManager):
         """Create the OMOTES interface.
 
         NOTE: Needs to be started separately.
 
         :param rabbitmq_config: RabbitMQ configuration how to connect to OMOTES.
+        :param possible_workflows: Container for all workflows which are expected to exist.
         """
         self.broker_if = BrokerInterface(rabbitmq_config)
+        self.workflow_type_manager = possible_workflows
 
     def start(self) -> None:
         """Start any other interfaces."""
@@ -125,8 +136,10 @@ class OmotesInterface:
         once the result is received and handled without exceptions through `callback_on_finished`.
         """
         if auto_disconnect_on_result:
+            logger.info("Connecting to update for job %s with auto disconnect on result", job.id)
             auto_disconnect_handler = self.disconnect_from_submitted_job
         else:
+            logger.info("Connecting to update for job %s and expect manual disconnect", job.id)
             auto_disconnect_handler = None
 
         callback_handler = JobSubmissionCallbackHandler(
@@ -157,7 +170,7 @@ class OmotesInterface:
     def submit_job(
         self,
         esdl: str,
-        params_dict: dict,
+        params_dict: ParamsDict,
         workflow_type: WorkflowType,
         job_timeout: Optional[timedelta],
         callback_on_finished: Callable[[Job, JobResult], None],
@@ -168,8 +181,9 @@ class OmotesInterface:
         """Submit a new job and connect to progress and status updates and the job result.
 
         :param esdl: String containing the XML that make up the ESDL.
-        :param params_dict: Dictionary containing any job-specific, non-ESDL, configuration parameters
-            dictionary supports: str, Union[Struct, ListValue, str, float, bool, None, Mapping[str, Any], Sequence]
+        :param params_dict: Dictionary containing any job-specific, non-ESDL, configuration
+            parameters. Dictionary supports:
+            str, Union[Struct, ListValue, str, float, bool, None, Mapping[str, Any], Sequence]
         :param workflow_type: Type of the workflow to start.
         :param job_timeout: How long the job may take before it is considered to be timeout.
         :param callback_on_finished: Callback which is called with the job result once the job is
@@ -177,12 +191,18 @@ class OmotesInterface:
         :param callback_on_progress_update: Callback which is called with any progress updates.
         :param callback_on_status_update: Callback which is called with any status updates.
         :param auto_disconnect_on_result: Remove/disconnect from all queues pertaining to this job
-        once the result is received and handled without exceptions through `callback_on_finished`.
+            once the result is received and handled without exceptions through
+            `callback_on_finished`.
+        :raises UnknownWorkflowException: If `workflow_type` is unknown as a possible workflow in
+            this interface.
         :return: The job handle which is created. This object needs to be saved persistently by the
             program using this SDK in order to resume listening to jobs in progress after a restart.
         """
-        job = Job(id=uuid.uuid4(), workflow_type=workflow_type)
+        if not self.workflow_type_manager.workflow_exists(workflow_type):
+            raise UnknownWorkflowException()
 
+        job = Job(id=uuid.uuid4(), workflow_type=workflow_type)
+        logger.info("Submitting job %s", job.id)
         self.connect_to_submitted_job(
             job,
             callback_on_finished,
@@ -205,6 +225,7 @@ class OmotesInterface:
             OmotesQueueNames.job_submission_queue_name(workflow_type),
             message=job_submission_msg.SerializeToString(),
         )
+        logger.debug("Done submitting job %s", job.id)
 
         return job
 
@@ -217,7 +238,8 @@ class OmotesInterface:
 
         :param job: The job to cancel.
         """
+        logger.info("Cancelling job %s", job.id)
         cancel_msg = JobCancel(uuid=str(job.id))
         self.broker_if.send_message_to(
-            OmotesQueueNames.job_cancel_queue_name(job), message=cancel_msg.SerializeToString()
+            OmotesQueueNames.job_cancel_queue_name(), message=cancel_msg.SerializeToString()
         )
